@@ -13,9 +13,9 @@ for i in cmdlist:
     if i.istitle():
         c += 1
 d = len(cmdlist) - c
-__version__ = str(c) + '.' + str(d) + '.' + '65' #easy_functions版本号
+__version__ = str(c) + '.' + str(d) + '.' + '69' #easy_functions版本号
 __author__ = 'Jerry\n我的QQ号：2711893794' #作者
-class FunctionSyntaxError(Exception):
+class FunctionSyntaxError(Exception): #异常
     def __init__(self, *error):
         pass
 def bigfont( name ): #大字显示
@@ -167,14 +167,30 @@ def title( title ): #更改标题
     import os
     os.system("title " + title)
     return
-def find_file( file ): #检测前置文件
-    try:
-        f = open(file,'r')
-    except FileNotFoundError:
-        return False
+def find_file(file, mode): #检测文件是否存在
+    if not type(file) == type('str'):
+        raise FunctionSyntaxError(
+            '需要输入字符串，而你输入的是%s'%type(file)
+        )
+    if mode == 'exist?':
+        try:
+            f = open(file,'r')
+        except FileNotFoundError:
+            return False
+        else:
+            f.close()
+            return True
+    elif mode == 'import?':
+        try:
+            __import__(file)
+        except ModuleNotFoundError:
+            return False
+        else:
+            return True
     else:
-        f.close()
-        return True
+        raise FunctionSyntaxError(
+            '没有模式"%s"'%mode
+        )
 def start( path ): #文件运行
     import os
     return os.system("start " + path)
@@ -267,12 +283,12 @@ def color( color ): #更改颜色
             coloroutrange = color[1]
         except IndexError as e:
             raise FunctionSyntaxError(
-                '%s不是一个完整的颜色编码'%color
+                '"%s"不是一个完整的颜色编码'%color
             ) from e
         else:
             if color[0].isupper() or color[1].isupper():
                 raise FunctionSyntaxError(
-                    '%s中含有大写字母，颜色编码必须小写'%color
+                    '"%s"中含有大写字母，颜色编码必须小写'%color
                 )
             elif color[0] in colorfontlist and color[1] in colorbacklist:
                 os.system('color ' + color)
@@ -284,11 +300,11 @@ def color( color ): #更改颜色
                 os.system('color ' + color)
             else:
                 raise FunctionSyntaxError(
-                    '无效颜色编码%s'%color
+                    '无效颜色编码"%s"'%color
                 ) from e
     else:
         raise FunctionSyntaxError(
-            '不支持2个以上的颜色编码%s'%color
+            '不支持2个以上的颜色编码"%s"'%color
         )
     return
 def mode(cols, lines): #更改cmd外框大小
@@ -482,11 +498,18 @@ def log(): #更新日志
     print('')
     print('[2021-6-18] [2条更新]')
     print('1.在功能copy中增加了一条检测语句，使文件不存在时报错')
-    print('2.增加了pause功能，具体使用helpcmd()查看')
+    print('2.增加了pause功能，具体请使用helpcmd()查看')
     print('')
     print('[2021-6-19] [1条更新]')
     print('1.对功能color的报错进行了优化')
     print('')
+    print('[2021-6-20] [1条更新]')
+    print('1.升级了功能find_file，使得此功能可以判断文件是否可以被导入')
+    print('2.在功能find_file中增加了一个位置参数，使得此功能拥有两个模式，具体请使用helpcmd()查看')
+    print('')
+    print('[2021-6-21] [1条更新]')
+    print('1.在功能find_file中添加了一条if语句，使用户没有输入字符串时报错')
+    print('')
     return
 def version(): #版本
     global __version__
@@ -536,7 +559,10 @@ def helpcmd( cmd ): #文件命令功能解释
         return
     if cmd == 'find_file':
         print('<',cmd,'>','文件检测功能')
-        print("用法：文件名或<import...as...>命令别名.find_file('文件路径')")
+        print("用法：文件名或<import...as...>命令别名.find_file('文件路径','模式')")
+        print('共有两种模式可用：')
+        print('1."exist?"判断文件是否存在，返回布尔值')
+        print('2."import?"判断文件是否可以被导入，返回布尔值')
         return
     if cmd == 'start':
         print('<',cmd,'>','文件运行功能')
